#include <tcl.h>
#include <tk.h>
#include "defs.h"

/* Interface between Tcl scripts and C code; allows Tcl scripts to */
/* use the C code (in concat.c) that concatenates 4 ppm files and */
/* dumps them to the Tk photo widget. */
int CatPPMCmd(ClientData clientData, Tcl_Interp *interp, int argc,
              char **argv)
{
  char* filenames[4];
  int i;
  PhotoHandle pp;
  if (argc != 6)
    {
      interp->result = "wrong # args";
      return TCL_ERROR;
    }
  pp = FindPhoto(argv[1]);
  if (pp == NULL)
    {
      interp->result = "bad photo handle";
      return TCL_ERROR;
    }
  for (i=0; i<4; i++)
    filenames[i] = argv[i+2];
  concat_files(pp, filenames);
  return TCL_OK;
}

/* Assumes argv[1] is a Tcl script.  Creates a Tcl interpreter; */
/* initializes Tk and its photo widget; registers a Tcl command called */
/* catppm, which when called from the Tcl script invokes the C */
/* function CatPPMCmd (above); executes the Tcl script whose name is */
/* in argv[1], and exits. */ 
main(int argc, char **argv)
{
  Tcl_Interp *interp;
  Tk_Window tkwin;
  char *displayname = NULL;
  char *name = "test";
  int code;
  
  interp = Tcl_CreateInterp();
  if ((tkwin = Tk_CreateMainWindow(interp, displayname, name, "Tk")) == NULL)
    {
      fprintf(stderr, "%s\n", interp->result);
      exit(1);
    }
  Tcl_SetVar(interp, "tcl_interactive", isatty(0) ? "1" : "0",
	     TCL_GLOBAL_ONLY);
  if (Tcl_Init(interp) == TCL_ERROR)
    {
      fprintf(stderr, "Tcl_Init failed: %s\n", interp->result);
    }
  if (Tk_Init(interp) == TCL_ERROR)
    {
      fprintf(stderr, "Tk_Init failed: %s\n", interp->result);
    }
  if (Photo_Init(interp) == TCL_ERROR)
    {
      fprintf(stderr, "Tk_Init failed: %s\n", interp->result);
    }
  Tcl_CreateCommand(interp, "catppm", CatPPMCmd, (ClientData)NULL,
                    (Tcl_CmdDeleteProc*)NULL);
  code = Tcl_EvalFile(interp, argv[1]);
  if (*interp->result != 0)
    printf("%s\n", interp->result);
  if (code != TCL_OK)
    exit(1);
  Tk_MainLoop();
  exit(0);
}

